@@ -19,37 +19,19 @@ import logging
 import platform
 
 if platform.system() == 'Windows':
-    import win32com.client
     import pythoncom
+    from win32com import client
 
 # external packages
-from PyQt5.QtCore import QObject, pyqtSignal, QTimer
+from PyQt5.QtCore import QTimer
 from PyQt5.QtTest import QTest
 
 # local imports
 from base.tpool import Worker
+from base.driverDataClass import DriverData, Signals
 
 
-class AscomSignals(QObject):
-
-    """
-    The AscomSignals class offers a list of signals to be used and instantiated
-    by the Ascom class to get signals for triggers for finished tasks to
-    enable a gui to update their values transferred to the caller back.
-
-    This has to be done in a separate class as the signals have to be subclassed
-    from QObject and the Mount class itself is subclassed from object
-    """
-
-    __all__ = ['AscomSignals']
-
-    serverConnected = pyqtSignal()
-    serverDisconnected = pyqtSignal(object)
-    deviceConnected = pyqtSignal(str)
-    deviceDisconnected = pyqtSignal(str)
-
-
-class AscomClass(object):
+class AscomClass(DriverData, Signals):
     """
     the class AscomClass inherits all information and handling of ascom devices
     this class will be only referenced from other classes and not directly used
@@ -58,8 +40,6 @@ class AscomClass(object):
     """
 
     log = logging.getLogger(__name__)
-
-    # relaxed generic timing
     CYCLE_POLL_STATUS = 3000
     CYCLE_POLL_DATA = 3000
 
@@ -68,10 +48,11 @@ class AscomClass(object):
 
         self.app = app
         self.threadPool = threadPool
-        self.ascomSignals = AscomSignals()
+        self.ascomSignals = Signals()
 
         self.client = None
         self.data = data
+        self.propertyExceptions = []
         self.deviceName = ''
         self.defaultConfig = {
             'ascom': {
@@ -94,6 +75,7 @@ class AscomClass(object):
         """
         :return:
         """
+        self.propertyExceptions = []
         self.client.connected = True
         return True
 
@@ -101,6 +83,7 @@ class AscomClass(object):
         """
         :return:
         """
+        self.propertyExceptions = []
         self.client.connected = False
         return True
 
@@ -110,23 +93,29 @@ class AscomClass(object):
         """
         return self.client.connected
 
-    def getInitialConfig(self):
+    def workerConnectAscomDevice(self):
         """
-        :return: success of reconnecting to server
+        As some ASCOM devices need some time to be able to connect, we try to
+        connect multiply (10) times with an waiting period 0f 250ms, so 2,5
+        seconds in total.
+
+        :return: true for test purpose
         """
         for retry in range(0, 10):
             try:
                 self.connectClient()
+                self.log.debug(f'Connect to [{self.deviceName}]')
 
             except Exception as e:
                 suc = False
-                self.log.warning(f'Connection error [{self.deviceName}]: [{e}]')
+                t = f'Connection retry [{retry}]: [{self.deviceName}]: [{e}]'
+                self.log.warning(t)
 
             else:
                 suc = self.isClientConnected()
                 if suc:
-                    text = f'[{self.deviceName}] connected, [{retry}] retries'
-                    self.log.debug(text)
+                    t = f'[{self.deviceName}] connected, [{retry}] retries'
+                    self.log.debug(t)
                     break
 
             finally:
@@ -147,7 +136,12 @@ class AscomClass(object):
             self.deviceConnected = True
             self.ascomSignals.deviceConnected.emit(f'{self.deviceName}')
             self.app.message.emit(f'ASCOM device found:  [{self.deviceName}]', 0)
+        return True
 
+    def workerGetInitialConfig(self):
+        """
+        :return: true for test purpose
+        """
         self.data['DRIVER_INFO.DRIVER_NAME'] = self.client.Name
         self.data['DRIVER_INFO.DRIVER_VERSION'] = self.client.DriverVersion
         self.data['DRIVER_INFO.DRIVER_EXEC'] = self.client.DriverInfo
@@ -169,33 +163,80 @@ class AscomClass(object):
         self.cyclePollStatus.stop()
         return True
 
-    def dataEntry(self, value, element, elementInv=None):
+    def getAscomProperty(self, valueProp):
         """
+        :param valueProp:
+        :return: value
+        """
+        value = None
+        if valueProp in self.propertyExceptions:
+            return value
+
+        try:
+            cmd = 'self.client.' + valueProp
+            value = eval(cmd)
+        except Exception as e:
+            t = f'Property [{valueProp}] is not implemented: {e}, cmd: [{cmd}]'
+            self.log.debug(t)
+            self.propertyExceptions.append(valueProp)
+        else:
+            self.log.trace(f'Property [{valueProp}] has value: [{value}]')
+        finally:
+            return value
+
+    def setAscomProperty(self, valueProp, value):
+        """
+        :param valueProp:
         :param value:
+        """
+        if valueProp in self.propertyExceptions:
+            return False
+
+        try:
+            cmd = 'self.client.' + valueProp + ' = value'
+            exec(cmd)
+        except Exception as e:
+            t = f'Property [{valueProp}] is not implemented: {e}, cmd: [{cmd}]'
+            self.log.debug(t)
+            self.propertyExceptions.append(valueProp)
+            return False
+        else:
+            self.log.trace(f'Property [{valueProp}] is set to [{value}]')
+            return True
+
+    def callAscomMethod(self, method, param):
+        """
+        :param method:
+        :param param:
+        """
+        if method in self.propertyExceptions:
+            return False
+
+        paramStr = f'{param}'.rstrip(')').lstrip('(')
+        try:
+            cmd = 'self.client.' + method + f'({paramStr})'
+            exec(cmd)
+        except Exception as e:
+            t = f'Method [{method}] is not implemented: {e}, cmd: [{cmd}]'
+            self.log.debug(t)
+            self.propertyExceptions.append(method)
+            return False
+        else:
+            self.log.trace(f'Method [{method}] is set to [{param}]')
+            return True
+
+    def getAndStoreAscomProperty(self, valueProp, element, elementInv=None):
+        """
+        :param valueProp:
         :param element:
         :param elementInv:
         :return: reset entry
         """
-        resetValue = value is None and element in self.data
-        if resetValue:
-            del self.data[element]
+        value = self.getAscomProperty(valueProp)
+        self.storePropertyToData(value, element, elementInv)
+        return True
 
-        else:
-            self.data[element] = value
-
-        if elementInv is None:
-            return resetValue
-
-        resetValue = value is None and elementInv in self.data
-        if resetValue:
-            del self.data[elementInv]
-
-        else:
-            self.data[elementInv] = value
-
-        return resetValue
-
-    def pollStatusWorker(self):
+    def workerPollStatus(self):
         """
         :return: success
         """
@@ -221,17 +262,43 @@ class AscomClass(object):
 
         return suc
 
-    def callMethodThreaded(self, fn, *args, **kwargs):
+    @staticmethod
+    def callerInitUnInit(fn, *args, **kwargs):
         """
-        :param fn:
+        :return: success
+        """
+        pythoncom.CoInitialize()
+        result = fn(*args, **kwargs)
+        pythoncom.CoUninitialize()
+        return result
+
+    def callMethodThreaded(self, fn, cb_res=None, cb_fin=None, check=True, *args, **kwargs):
+        """
+        callMethodThreaded is done mainly for ASCOM ctypes interfaces which take
+        longer to end and should not slow down the gui thread itself. All called
+        functions run in PyQt5 threadPool and could have callback after result is
+        processed or the thread task is finished. It does not call directly the
+        defined function, but the callerInitUnInit method, which does the necessary
+        pythoncom.Initialize() before running win32 functions in another thread
+        than the dispatch was done (in our case the main gui thread) and call
+        pythoncom.CoUninitialize() after the functions finished.
+
+        :param fn: function
+        :param cb_res: callback
+        :param cb_fin: callback
+        :param check: callback
         :param args:
         :param kwargs:
         :return:
         """
-        if not self.deviceConnected:
+        if check and not self.deviceConnected:
             return False
 
-        worker = Worker(fn, *args, **kwargs)
+        worker = Worker(self.callerInitUnInit, fn, *args, **kwargs)
+        if cb_res:
+            worker.signals.finished.connect(cb_res)
+        if cb_fin:
+            worker.signals.finished.connect(cb_fin)
         self.threadPool.start(worker)
         return True
 
@@ -251,20 +318,22 @@ class AscomClass(object):
         """
         :return: success
         """
-        if not self.deviceConnected:
-            return False
-
-        worker = Worker(self.workerPollData)
-        worker.signals.result.connect(self.processPolledData)
-        self.threadPool.start(worker)
+        self.callMethodThreaded(self.workerPollData,
+                                cb_res=self.processPolledData)
         return True
 
     def pollStatus(self):
         """
         :return: success
         """
-        worker = Worker(self.pollStatusWorker)
-        self.threadPool.start(worker)
+        self.callMethodThreaded(self.workerPollStatus)
+        return True
+
+    def getInitialConfig(self):
+        """
+        :return: success
+        """
+        self.callMethodThreaded(self.workerGetInitialConfig)
         return True
 
     def startCommunication(self, loadConfig=False):
@@ -275,20 +344,19 @@ class AscomClass(object):
         if not self.deviceName:
             return False
 
-        # clsctx = pythoncom.CLSCTX_LOCAL_SERVER
-        pythoncom.CoInitialize()
         try:
-            self.client = win32com.client.Dispatch(self.deviceName)
+            self.client = client.dynamic.Dispatch(self.deviceName)
+            self.log.debug(f'Dispatch [{self.deviceName}]')
 
         except Exception as e:
             self.log.error(f'Dispatch for [{self.deviceName}] error: {e}')
             return False
 
         else:
-            worker = Worker(self.getInitialConfig)
-            worker.signals.finished.connect(self.startTimer)
-            self.threadPool.start(worker)
-
+            self.callMethodThreaded(self.workerConnectAscomDevice,
+                                    check=False,
+                                    cb_res=self.getInitialConfig,
+                                    cb_fin=self.startTimer)
         return True
 
     def stopCommunication(self):
@@ -301,13 +369,17 @@ class AscomClass(object):
                 self.disconnectClient()
 
             except Exception as e:
-                text = f'Connection to [{self.deviceName}] could not be closed, {e}'
-                self.log.debug(text)
+                t = f'Connection to [{self.deviceName}] could not be closed, {e}'
+                self.log.debug(t)
+
+            else:
+                t = f'Connection to [{self.deviceName}] closed'
+                self.log.debug(t)
 
         self.deviceConnected = False
         self.serverConnected = False
         self.client = None
-        pythoncom.CoUninitialize()
+        self.propertyExceptions = []
         self.ascomSignals.deviceDisconnected.emit(f'{self.deviceName}')
         self.ascomSignals.serverDisconnected.emit({f'{self.deviceName}': 0})
         self.app.message.emit(f'ASCOM device remove: [{self.deviceName}]', 0)
