@@ -110,6 +110,7 @@ class IndiClass:
         self.client = qtIndiBase.Client(host=None, threadPool=threadPool)
         self.deviceName = ''
         self.device = None
+        self.deviceConnected = False
         self._hostaddress = None
         self._host = None
         self._port = None
@@ -247,8 +248,8 @@ class IndiClass:
         """
         if not self.deviceName:
             return False
-
         if self.data:
+            self.deviceConnected = True
             return True
 
         self.retryCounter += 1
@@ -260,7 +261,7 @@ class IndiClass:
         self.log.debug(t)
         if self.retryCounter < self.NUMBER_RETRY:
             self.timerRetry.start(self.RETRY_DELAY)
-        return True
+        return False
 
     def startCommunication(self, loadConfig=False):
         """
@@ -285,6 +286,7 @@ class IndiClass:
         self.client.stopTimers()
         suc = self.client.disconnectServer(self.deviceName)
         self.deviceName = ''
+        self.deviceConnected = False
         return suc
 
     def connectDevice(self, deviceName, propertyName):
