@@ -47,13 +47,13 @@ class DownloadPopup(toolsQtWidget.MWidget):
                  parentWidget,
                  url='',
                  dest='',
+                 unzip=True,
                  callBack=None,
                  ):
 
         super().__init__()
         self.ui = Ui_DownloadPopup()
         self.ui.setupUi(self)
-        self.initUI()
         self.callBack = callBack
         self.worker = None
         self.setWindowModality(Qt.ApplicationModal)
@@ -67,7 +67,7 @@ class DownloadPopup(toolsQtWidget.MWidget):
         self.threadPool = parentWidget.threadPool
         self.signalProgress.connect(self.setProgressBarToValue)
         self.signalProgressBarColor.connect(self.setProgressBarColor)
-        self.downloadFile(url, dest)
+        self.downloadFile(url, dest, unzip=unzip)
         self.show()
 
     def setProgressBarColor(self, color):
@@ -123,15 +123,15 @@ class DownloadPopup(toolsQtWidget.MWidget):
 
         return True
 
-    def downloadFileWorker(self, url, dest):
+    def downloadFileWorker(self, url, dest, unzip=True):
         """
         :param url:
         :param dest:
+        :param unzip:
         :return:
         """
         if not os.path.dirname(dest):
             return False
-
         if os.path.isfile(dest):
             os.remove(dest)
 
@@ -156,6 +156,9 @@ class DownloadPopup(toolsQtWidget.MWidget):
         finally:
             time.sleep(1)
 
+        if not unzip:
+            return True
+
         try:
             self.unzipFile(dest)
 
@@ -174,20 +177,19 @@ class DownloadPopup(toolsQtWidget.MWidget):
         self.close()
         return True
 
-    def downloadFile(self, url, dest):
+    def downloadFile(self, url, dest, unzip=True):
         """
         :param url:
         :param dest:
+        :param unzip:
         :return:
         """
-        self.worker = Worker(self.downloadFileWorker, url=url, dest=dest)
-
+        self.worker = Worker(self.downloadFileWorker, url=url, dest=dest,
+                             unzip=unzip)
         if self.callBack:
             self.worker.signals.result.connect(self.processResult)
-
         else:
             self.worker.signals.result.connect(self.close)
 
         self.threadPool.start(self.worker)
-
         return True
