@@ -26,6 +26,7 @@ from PyQt5.QtGui import QPalette, QIcon, QPixmap
 from PyQt5.QtCore import QSortFilterProxyModel, QDir, QObject, pyqtSignal
 from PyQt5.QtCore import Qt, QSize, QEvent
 from skyfield.api import Angle
+import numpy as np
 
 # local imports
 from gui.utilities.stylesQtCss import Styles
@@ -45,7 +46,6 @@ class FileSortProxyModel(QSortFilterProxyModel):
     file dialogues. The sorting is now Descending meaning the last added files
     will be on top. This is don by just overwriting the sort method
     """
-
     def sort(self, column, order):
         self.sourceModel().sort(0, Qt.DescendingOrder)
 
@@ -60,7 +60,6 @@ class QMultiWait(QObject):
 
     in addition all received signals could be reset
     """
-
     ready = pyqtSignal()
 
     def __init__(self):
@@ -121,6 +120,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         newFlag = Qt.CustomizeWindowHint | Qt.WindowSystemMenuHint
         newFlag = newFlag | Qt.WindowMinimizeButtonHint | Qt.WindowMaximizeButtonHint
         self.setWindowFlags(self.windowFlags() | newFlag)
+        self.setWindowIcon(QIcon(':/icon/mw4.png'))
 
     @staticmethod
     def wIcon(gui=None, name=''):
@@ -155,7 +155,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         """
         if platform.system() == 'Darwin':
             return self.MAC_STYLE + self.BASIC_STYLE
-
         else:
             return self.NON_MAC_STYLE + self.BASIC_STYLE
 
@@ -178,7 +177,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
     @staticmethod
     def changeStyleDynamic(widget=None, widgetProperty=None, value=None):
         """
-        changeStyleDynamic changes the stylesheet of a given uii element and
+        changeStyleDynamic changes the stylesheet of a given ui element and
         makes it visible. therefore the element has to be unpolished and
         polished again.
 
@@ -201,7 +200,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         widget.style().unpolish(widget)
         widget.setProperty(widgetProperty, value)
         widget.style().polish(widget)
-
         return True
 
     @staticmethod
@@ -240,7 +238,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
         if len(names) == 1:
             return nameList[0], shortList[0], extList[0]
-
         else:
             return nameList, shortList, extList
 
@@ -269,13 +266,11 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
         if enableDir:
             dlg.setFilter(QDir.Files | QDir.AllDirs)
-
         else:
             dlg.setFilter(QDir.Files)
 
         width = 600
         height = 400
-
         ph = window.geometry().height()
         pw = window.geometry().width()
         px = window.geometry().x()
@@ -285,7 +280,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
                         py + int(0.5 * (ph - height)),
                         width,
                         height)
-
         return dlg
 
     @staticmethod
@@ -320,7 +314,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
         if reply != msg.Yes:
             return False
-
         else:
             return True
 
@@ -346,16 +339,12 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
                             short: just file name without extension
                             ext: extension of the file
         """
-
         if not window:
             return '', '', ''
-
         if not title:
             return '', '', ''
-
         if not folder:
             return '', '', ''
-
         if not filterSet:
             return '', '', ''
 
@@ -370,18 +359,15 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
         if multiple:
             dlg.setFileMode(QFileDialog.ExistingFiles)
-
         else:
             dlg.setFileMode(QFileDialog.ExistingFile)
 
         result = self.runDialog(dlg)
-
         if not result:
             return '', '', ''
 
         filePath = dlg.selectedFiles()
         full, short, ext = self.extractNames(names=filePath)
-
         return full, short, ext
 
     def saveFile(self,
@@ -402,34 +388,26 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
                             short: just file name without extension
                             ext: extension of the file
         """
-
         if not window:
             return '', '', ''
-
         if not title:
             return '', '', ''
-
         if not folder:
             return '', '', ''
-
         if not filterSet:
             return '', '', ''
 
         dlg = self.prepareFileDialog(window, enableDir)
         dlg.setAcceptMode(QFileDialog.AcceptSave)
-
         dlg.setWindowTitle(title)
         dlg.setNameFilter(filterSet)
         dlg.setDirectory(folder)
-
         result = self.runDialog(dlg)
-
         if not result:
             return '', '', ''
 
         filePath = dlg.selectedFiles()
         full, short, ext = self.extractNames(names=filePath)
-
         return full, short, ext
 
     def openDir(self,
@@ -446,40 +424,34 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
                             short: just file name without extension
                             ext: extension of the file
         """
-
         if not window:
             return '', '', ''
-
         if not title:
             return '', '', ''
-
         if not folder:
             return '', '', ''
 
         dlg = self.prepareFileDialog(window=window, enableDir=True)
         dlg.setAcceptMode(QFileDialog.AcceptOpen)
-
         dlg.setWindowTitle(title)
         dlg.setDirectory(folder)
         dlg.setFileMode(QFileDialog.DirectoryOnly)
-
         result = self.runDialog(dlg)
-
         if not result:
             return '', '', ''
 
         filePath = dlg.selectedFiles()
         full, short, ext = self.extractNames(names=filePath)
-
         return full, short, ext
 
     @staticmethod
     def clickable(widget=None):
         """
-        It uses one filter object per label, which is created when the clickable()
-        function is called with the widget that is to be click-enabled. The function
-        returns a clicked() signal that actually belongs to the filter object. The caller
-        can connect this signal to a suitable callable object.
+        It uses one filter object per label, which is created when the
+        clickable() function is called with the widget that is to be
+        click-enabled. The function returns a clicked() signal that actually
+        belongs to the filter object. The caller can connect this signal to a
+        suitable callable object.
 
         :param widget:      widget for what the event filter works
         :return:            filtered event
@@ -507,61 +479,92 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
         doubleClickEventFilter = MouseDoubleClickEventFilter(widget)
         widget.installEventFilter(doubleClickEventFilter)
-
         return doubleClickEventFilter.clicked
 
-    @staticmethod
-    def guiSetText(ui, formatElement, value=None):
+    def guiSetText(self, ui, formatElement, value=None):
         """
-
         :param ui:
         :param formatElement:
         :param value:
         :return: True for test purpose
         """
-
         if not ui:
             return False
-
         if not formatElement:
             return False
-
         if value is None:
             text = '-'
-
+        elif isinstance(value, (list, np.ndarray)) and len(value) == 0:
+            text = '-'
+        elif formatElement.startswith('HSTR'):
+            text = self.formatHstrToText(value)
+        elif formatElement.startswith('DSTR'):
+            text = self.formatDstrToText(value)
+        elif formatElement.startswith('D'):
+            formatStr = '{0:' + formatElement.lstrip('D') + '}'
+            text = formatStr.format(value.degrees)
+        elif formatElement.startswith('H'):
+            formatStr = '{0:' + formatElement.lstrip('H') + '}'
+            text = formatStr.format(value.hours)
+        elif value == 'E':
+            text = 'EAST'
+        elif value == 'W':
+            text = 'WEST'
+        elif isinstance(value, bool):
+            if value:
+                text = 'ON'
+            else:
+                text = 'OFF'
         else:
             formatStr = '{0:' + formatElement + '}'
             text = formatStr.format(value)
 
         ui.setText(text)
+        return True
 
+    def guiSetStyle(self, ui, pStyle='', value=None, pVals=['', '', '']):
+        """
+        :param ui:
+        :param pStyle:
+        :param value:
+        :param pVals:
+        :return:
+        """
+        if not pStyle:
+            return False
+        if value is None:
+            pVal = pVals[0]
+        elif value:
+            pVal = pVals[1]
+        else:
+            pVal = pVals[2]
+
+        self.changeStyleDynamic(ui, pStyle, pVal)
         return True
 
     @staticmethod
     def returnDriver(sender, searchDict, addKey=''):
         """
-        returnDriver takes the sender widget from a gui interaction and compares is to the
-        widget objects of a search dicts to retrieve is original name.
-        therefore we need to swap key value pais in the search dict as we make a reverse
-        search.
-        in addition to make it more usable the search dict might have some sub dicts where
-        to find the gui elements. if given, the will be extracted on the forehand.
+        returnDriver takes the sender widget from a gui interaction and compares
+        is to the widget objects of a search dicts to retrieve is original name.
+        therefore we need to swap key value pais in the search dict as we make a
+        reverse search.
+        in addition to make it more usable the search dict might have some sub
+        dicts where to find the gui elements. if given, the will be extracted on
+        the forehand.
 
         :param sender:
         :param searchDict:
         :param addKey:
         :return:
         """
-
         if addKey:
             searchD = dict([(key, value[addKey]) for key, value in searchDict.items()])
-
         else:
             searchD = searchDict
 
         searchD = dict([(value, key) for key, value in searchD.items()])
         driver = searchD.get(sender, '')
-
         return driver
 
     @staticmethod
@@ -592,7 +595,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
                 angle += float(elements[10]) / 3600
             if elements[4].startswith(pf[0]):
                 angle = -angle
-
         else:
             return None
 
@@ -603,7 +605,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
         if angle > maxAbs:
             return None
-
         elif angle < -maxAbs:
             return None
 
@@ -653,26 +654,21 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
         if isFloat:
             angle = float(value.replace(',', '.'))
-
         elif isSexagesimal:
             angle = float(elements[2])
             if elements[3] is not None:
                 angle += float(elements[3]) / 60
             if elements[4] is not None:
                 angle += float(elements[4]) / 3600
-
         else:
             return None
 
         if angle >= 24:
             return None
-
         if angle < 0:
             return None
-
         if isFloat:
             angle = Angle(hours=angle / 360 * 24)
-
         elif isSexagesimal:
             angle = Angle(hours=angle)
 
@@ -719,7 +715,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
         if angle > 90:
             return None
-
         if angle < -90:
             return None
 
